@@ -32,8 +32,8 @@ def inference(img_path,ocr,cvdnn_path):
             image= cv2.imread(img_path)
             img_path=upsacale(image,cvdnn_path)
             #img_path=predark(img_path)
-            cv2.imwrite("test.jpg",img_path)
             result = ocr.ocr(img_path, cls=True)
+            result=result[0]
             txts1 = [line[1][0] for line in result]
             scores1 = [line[1][1] for line in result]
             if len(txts1)==0:          #no object detected
